@@ -10,7 +10,7 @@ use rustpython_parser::ast::{
 };
 use rustpython_parser::parser;
 
-use crate::ast::helpers::{match_name_or_attr, SubscriptKind};
+use crate::ast::helpers::{extract_handler_names, match_name_or_attr, SubscriptKind};
 use crate::ast::operations::{extract_all_names, SourceCodeLocator};
 use crate::ast::relocate::relocate_expr;
 use crate::ast::types::{
@@ -60,6 +60,7 @@ pub struct Checker<'a> {
     seen_docstring: bool,
     futures_allowed: bool,
     annotations_future_enabled: bool,
+    except_handlers: Vec<Vec<String>>,
 }
 
 impl<'a> Checker<'a> {
@@ -74,25 +75,26 @@ impl<'a> Checker<'a> {
             autofix,
             path,
             locator: SourceCodeLocator::new(content),
-            checks: vec![],
-            parents: vec![],
-            parent_stack: vec![],
-            scopes: vec![],
-            scope_stack: vec![],
-            dead_scopes: vec![],
-            deferred_string_annotations: vec![],
-            deferred_annotations: vec![],
-            deferred_functions: vec![],
-            deferred_lambdas: vec![],
-            deferred_assignments: vec![],
-            in_f_string: None,
-            in_annotation: false,
-            in_literal: false,
-            seen_non_import: false,
-            seen_docstring: false,
-            futures_allowed: true,
-            annotations_future_enabled: false,
+            checks: Default::default(),
             deletions: Default::default(),
+            parents: Default::default(),
+            parent_stack: Default::default(),
+            scopes: Default::default(),
+            scope_stack: Default::default(),
+            dead_scopes: Default::default(),
+            deferred_string_annotations: Default::default(),
+            deferred_annotations: Default::default(),
+            deferred_functions: Default::default(),
+            deferred_lambdas: Default::default(),
+            deferred_assignments: Default::default(),
+            in_f_string: None,
+            in_annotation: Default::default(),
+            in_literal: Default::default(),
+            seen_non_import: Default::default(),
+            seen_docstring: Default::default(),
+            futures_allowed: true,
+            annotations_future_enabled: Default::default(),
+            except_handlers: Default::default(),
         }
     }
 }
@@ -546,10 +548,13 @@ where
                     plugins::if_tuple(self, stmt, test);
                 }
             }
-            StmtKind::Assert { test, .. } => {
+            StmtKind::Assert { test, msg } => {
                 if self.settings.enabled.contains(&CheckCode::F631) {
                     plugins::assert_tuple(self, stmt, test);
                 }
+                if self.settings.enabled.contains(&CheckCode::B011) {
+                    plugins::assert_false(self, stmt, test, msg);
+                }
             }
             StmtKind::Try { handlers, .. } => {
                 if self.settings.enabled.contains(&CheckCode::F707) {
@@ -557,6 +562,11 @@ where
                         self.checks.push(check);
                     }
                 }
+                if self.settings.enabled.contains(&CheckCode::B014)
+                    || self.settings.enabled.contains(&CheckCode::B025)
+                {
+                    plugins::duplicate_exceptions(self, stmt, handlers);
+                }
             }
             StmtKind::Assign { targets, value, .. } => {
                 if self.settings.enabled.contains(&CheckCode::E731) {
@@ -601,6 +611,27 @@ where
                     self.visit_stmt(stmt);
                 }
             }
+            StmtKind::Try {
+                body,
+                handlers,
+                orelse,
+                finalbody,
+            } => {
+                self.except_handlers.push(extract_handler_names(handlers));
+                for stmt in body {
+                    self.visit_stmt(stmt);
+                }
+                self.except_handlers.pop();
+                for excepthandler in handlers {
+                    self.visit_excepthandler(excepthandler)
+                }
+                for stmt in orelse {
+                    self.visit_stmt(stmt);
+                }
+                for stmt in finalbody {
+                    self.visit_stmt(stmt);
+                }
+            }
             _ => visitor::walk_stmt(self, stmt),
         };
 
@@ -633,12 +664,20 @@ where
         let prev_in_annotation = self.in_annotation;
 
         if self.in_annotation && self.annotations_future_enabled {
-            self.deferred_annotations.push((
-                expr,
-                self.scope_stack.clone(),
-                self.parent_stack.clone(),
-            ));
-            visitor::walk_expr(self, expr);
+            if let ExprKind::Constant {
+                value: Constant::Str(value),
+                ..
+            } = &expr.node
+            {
+                self.deferred_string_annotations
+                    .push((Range::from_located(expr), value));
+            } else {
+                self.deferred_annotations.push((
+                    expr,
+                    self.scope_stack.clone(),
+                    self.parent_stack.clone(),
+                ));
+            }
             return;
         }
 
@@ -718,11 +757,11 @@ where
                 ..
             } => {
                 if self.settings.enabled.contains(&CheckCode::U005) {
-                    plugins::assert_equals(self, func);
+                    plugins::deprecated_unittest_alias(self, func);
                 }
 
                 // flake8-super
-                if self.settings.enabled.contains(&CheckCode::SPR001) {
+                if self.settings.enabled.contains(&CheckCode::U008) {
                     plugins::super_call_with_parameters(self, expr, func, args);
                 }
 
@@ -788,6 +827,21 @@ where
                     };
                 }
 
+                if self.settings.enabled.contains(&CheckCode::C409) {
+                    if let Some(check) =
+                        checks::unnecessary_literal_within_tuple_call(expr, func, args)
+                    {
+                        self.checks.push(check);
+                    };
+                }
+
+                if self.settings.enabled.contains(&CheckCode::C410) {
+                    if let Some(check) =
+                        checks::unnecessary_literal_within_list_call(expr, func, args)
+                    {
+                        self.checks.push(check);
+                    };
+                }
                 if self.settings.enabled.contains(&CheckCode::C415) {
                     if let Some(check) = checks::unnecessary_subscript_reversal(expr, func, args) {
                         self.checks.push(check);
@@ -1463,6 +1517,14 @@ impl<'a> Checker<'a> {
                 if self.path.ends_with("__init__.py") && id == "__path__" {
                     return;
                 }
+
+                // Avoid flagging if NameError is handled.
+                if let Some(handler_names) = self.except_handlers.last() {
+                    if handler_names.contains(&"NameError".to_string()) {
+                        return;
+                    }
+                }
+
                 self.checks.push(Check::new(
                     CheckKind::UndefinedName(id.clone()),
                     self.locate_check(Range::from_located(expr)),
