@@ -1,6 +1,7 @@
 use itertools::Itertools;
 use rustpython_parser::ast::Location;
 use serde::{Deserialize, Serialize};
+use std::str::FromStr;
 use strum_macros::{AsRefStr, EnumIter, EnumString};
 
 use crate::ast::checks::Primitive;
@@ -120,6 +121,10 @@ pub enum CheckCode {
     A001,
     A002,
     A003,
+    // flake8-bugbear
+    B011,
+    B014,
+    B025,
     // flake8-comprehensions
     C400,
     C401,
@@ -129,9 +134,9 @@ pub enum CheckCode {
     C405,
     C406,
     C408,
+    C409,
+    C410,
     C415,
-    // flake8-super
-    SPR001,
     // flake8-print
     T201,
     T203,
@@ -143,6 +148,7 @@ pub enum CheckCode {
     U005,
     U006,
     U007,
+    U008,
     // Meta
     M001,
 }
@@ -211,7 +217,11 @@ pub enum CheckKind {
     BuiltinVariableShadowing(String),
     BuiltinArgumentShadowing(String),
     BuiltinAttributeShadowing(String),
-    // flakes8-comprehensions
+    // flake8-bugbear
+    DoNotAssertFalse,
+    DuplicateHandlerException(String),
+    DuplicateTryBlockException(String),
+    // flake8-comprehensions
     UnnecessaryGeneratorList,
     UnnecessaryGeneratorSet,
     UnnecessaryGeneratorDict,
@@ -220,9 +230,9 @@ pub enum CheckKind {
     UnnecessaryLiteralSet(String),
     UnnecessaryLiteralDict(String),
     UnnecessaryCollectionCall(String),
+    UnnecessaryLiteralWithinTupleCall(String),
+    UnnecessaryLiteralWithinListCall(String),
     UnnecessarySubscriptReversal(String),
-    // flake8-super
-    SuperCallWithParameters,
     // flake8-print
     PrintFound,
     PPrintFound,
@@ -230,12 +240,13 @@ pub enum CheckKind {
     TypeOfPrimitive(Primitive),
     UnnecessaryAbspath,
     UselessMetaclassType,
-    NoAssertEquals,
+    DeprecatedUnittestAlias(String, String),
     UselessObjectInheritance(String),
     UsePEP585Annotation(String),
     UsePEP604Annotation,
+    SuperCallWithParameters,
     // Meta
-    UnusedNOQA(Option<String>),
+    UnusedNOQA(Option<Vec<String>>),
 }
 
 impl CheckCode {
@@ -303,6 +314,10 @@ impl CheckCode {
             CheckCode::A001 => CheckKind::BuiltinVariableShadowing("...".to_string()),
             CheckCode::A002 => CheckKind::BuiltinArgumentShadowing("...".to_string()),
             CheckCode::A003 => CheckKind::BuiltinAttributeShadowing("...".to_string()),
+            // flake8-bugbear
+            CheckCode::B011 => CheckKind::DoNotAssertFalse,
+            CheckCode::B014 => CheckKind::DuplicateHandlerException("Exception".to_string()),
+            CheckCode::B025 => CheckKind::DuplicateTryBlockException("Exception".to_string()),
             // flake8-comprehensions
             CheckCode::C400 => CheckKind::UnnecessaryGeneratorList,
             CheckCode::C401 => CheckKind::UnnecessaryGeneratorSet,
@@ -314,11 +329,15 @@ impl CheckCode {
             CheckCode::C408 => {
                 CheckKind::UnnecessaryCollectionCall("<dict/list/tuple>".to_string())
             }
+            CheckCode::C409 => {
+                CheckKind::UnnecessaryLiteralWithinTupleCall("<list/tuple>".to_string())
+            }
+            CheckCode::C410 => {
+                CheckKind::UnnecessaryLiteralWithinListCall("<list/tuple>".to_string())
+            }
             CheckCode::C415 => {
                 CheckKind::UnnecessarySubscriptReversal("<reversed/set/sorted>".to_string())
             }
-            // flake8-super
-            CheckCode::SPR001 => CheckKind::SuperCallWithParameters,
             // flake8-print
             CheckCode::T201 => CheckKind::PrintFound,
             CheckCode::T203 => CheckKind::PPrintFound,
@@ -327,9 +346,13 @@ impl CheckCode {
             CheckCode::U002 => CheckKind::UnnecessaryAbspath,
             CheckCode::U003 => CheckKind::TypeOfPrimitive(Primitive::Str),
             CheckCode::U004 => CheckKind::UselessObjectInheritance("...".to_string()),
-            CheckCode::U005 => CheckKind::NoAssertEquals,
+            CheckCode::U005 => CheckKind::DeprecatedUnittestAlias(
+                "assertEquals".to_string(),
+                "assertEqual".to_string(),
+            ),
             CheckCode::U006 => CheckKind::UsePEP585Annotation("List".to_string()),
             CheckCode::U007 => CheckKind::UsePEP604Annotation,
+            CheckCode::U008 => CheckKind::SuperCallWithParameters,
             // Meta
             CheckCode::M001 => CheckKind::UnusedNOQA(None),
         }
@@ -389,6 +412,10 @@ impl CheckKind {
             CheckKind::BuiltinVariableShadowing(_) => &CheckCode::A001,
             CheckKind::BuiltinArgumentShadowing(_) => &CheckCode::A002,
             CheckKind::BuiltinAttributeShadowing(_) => &CheckCode::A003,
+            // flake8-bugbear
+            CheckKind::DoNotAssertFalse => &CheckCode::B011,
+            CheckKind::DuplicateHandlerException(_) => &CheckCode::B014,
+            CheckKind::DuplicateTryBlockException(_) => &CheckCode::B025,
             // flake8-comprehensions
             CheckKind::UnnecessaryGeneratorList => &CheckCode::C400,
             CheckKind::UnnecessaryGeneratorSet => &CheckCode::C401,
@@ -398,9 +425,9 @@ impl CheckKind {
             CheckKind::UnnecessaryLiteralSet(_) => &CheckCode::C405,
             CheckKind::UnnecessaryLiteralDict(_) => &CheckCode::C406,
             CheckKind::UnnecessaryCollectionCall(_) => &CheckCode::C408,
+            CheckKind::UnnecessaryLiteralWithinTupleCall(..) => &CheckCode::C409,
+            CheckKind::UnnecessaryLiteralWithinListCall(..) => &CheckCode::C410,
             CheckKind::UnnecessarySubscriptReversal(_) => &CheckCode::C415,
-            // flake8-super
-            CheckKind::SuperCallWithParameters => &CheckCode::SPR001,
             // flake8-print
             CheckKind::PrintFound => &CheckCode::T201,
             CheckKind::PPrintFound => &CheckCode::T203,
@@ -408,10 +435,11 @@ impl CheckKind {
             CheckKind::TypeOfPrimitive(_) => &CheckCode::U003,
             CheckKind::UnnecessaryAbspath => &CheckCode::U002,
             CheckKind::UselessMetaclassType => &CheckCode::U001,
-            CheckKind::NoAssertEquals => &CheckCode::U005,
+            CheckKind::DeprecatedUnittestAlias(_, _) => &CheckCode::U005,
             CheckKind::UsePEP585Annotation(_) => &CheckCode::U006,
             CheckKind::UsePEP604Annotation => &CheckCode::U007,
             CheckKind::UselessObjectInheritance(_) => &CheckCode::U004,
+            CheckKind::SuperCallWithParameters => &CheckCode::U008,
             // Meta
             CheckKind::UnusedNOQA(_) => &CheckCode::M001,
         }
@@ -560,6 +588,17 @@ impl CheckKind {
             CheckKind::BuiltinAttributeShadowing(name) => {
                 format!("Class attribute `{name}` is shadowing a python builtin")
             }
+            // flake8-bugbear
+            CheckKind::DoNotAssertFalse => {
+                "Do not `assert False` (`python -O` removes these calls), raise `AssertionError()`"
+                    .to_string()
+            }
+            CheckKind::DuplicateHandlerException(name) => {
+                format!("Exception handler with duplicate exception `{name}`")
+            }
+            CheckKind::DuplicateTryBlockException(name) => {
+                format!("try-except block with duplicate exception `{name}`")
+            }
             // flake8-comprehensions
             CheckKind::UnnecessaryGeneratorList => {
                 "Unnecessary generator - rewrite as a list comprehension".to_string()
@@ -585,13 +624,31 @@ impl CheckKind {
             CheckKind::UnnecessaryCollectionCall(obj_type) => {
                 format!("Unnecessary {obj_type} call - rewrite as a literal")
             }
+            CheckKind::UnnecessaryLiteralWithinTupleCall(literal) => {
+                if literal == "list" {
+                    format!(
+                        "Unnecessary {literal} literal passed to tuple() - rewrite as a tuple literal"
+                    )
+                } else {
+                    format!(
+                        "Unnecessary {literal} literal passed to tuple() - remove the outer call to tuple()"
+                    )
+                }
+            }
+            CheckKind::UnnecessaryLiteralWithinListCall(literal) => {
+                if literal == "list" {
+                    format!(
+                        "Unnecessary {literal} literal passed to list() - remove the outer call to list()"
+                    )
+                } else {
+                    format!(
+                        "Unnecessary {literal} literal passed to list() - rewrite as a list literal"
+                    )
+                }
+            }
             CheckKind::UnnecessarySubscriptReversal(func) => {
                 format!("Unnecessary subscript reversal of iterable within {func}()")
             }
-            // flake8-super
-            CheckKind::SuperCallWithParameters => {
-                "Use `super()` instead of `super(__class__, self)`".to_string()
-            }
             // flake8-print
             CheckKind::PrintFound => "`print` found".to_string(),
             CheckKind::PPrintFound => "`pprint` found".to_string(),
@@ -603,8 +660,8 @@ impl CheckKind {
                 "`abspath(__file__)` is unnecessary in Python 3.9 and later".to_string()
             }
             CheckKind::UselessMetaclassType => "`__metaclass__ = type` is implied".to_string(),
-            CheckKind::NoAssertEquals => {
-                "`assertEquals` is deprecated, use `assertEqual` instead".to_string()
+            CheckKind::DeprecatedUnittestAlias(alias, target) => {
+                format!("`{}` is deprecated, use `{}` instead", alias, target)
             }
             CheckKind::UselessObjectInheritance(name) => {
                 format!("Class `{name}` inherits from object")
@@ -617,10 +674,25 @@ impl CheckKind {
                 )
             }
             CheckKind::UsePEP604Annotation => "Use `X | Y` for type annotations".to_string(),
+            CheckKind::SuperCallWithParameters => {
+                "Use `super()` instead of `super(__class__, self)`".to_string()
+            }
             // Meta
-            CheckKind::UnusedNOQA(code) => match code {
+            CheckKind::UnusedNOQA(codes) => match codes {
                 None => "Unused `noqa` directive".to_string(),
-                Some(code) => format!("Unused `noqa` directive for: {code}"),
+                Some(codes) => {
+                    let codes = codes
+                        .iter()
+                        .map(|code| {
+                            if CheckCode::from_str(code).is_ok() {
+                                code.to_string()
+                            } else {
+                                format!("{code} (not implemented)")
+                            }
+                        })
+                        .join(", ");
+                    format!("Unused `noqa` directive for: {codes}")
+                }
             },
         }
     }
@@ -629,7 +701,8 @@ impl CheckKind {
     pub fn fixable(&self) -> bool {
         matches!(
             self,
-            CheckKind::NoAssertEquals
+            CheckKind::DeprecatedUnittestAlias(_, _)
+                | CheckKind::DoNotAssertFalse
                 | CheckKind::PPrintFound
                 | CheckKind::PrintFound
                 | CheckKind::SuperCallWithParameters
