@@ -376,9 +376,57 @@ mod tests {
     }
 
     #[test]
-    fn f401() -> Result<()> {
+    fn f401_0() -> Result<()> {
         let mut checks = check_path(
-            Path::new("./resources/test/fixtures/F401.py"),
+            Path::new("./resources/test/fixtures/F401_0.py"),
+            &settings::Settings::for_rule(CheckCode::F401),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
+
+    #[test]
+    fn f401_1() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/F401_1.py"),
+            &settings::Settings::for_rule(CheckCode::F401),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
+
+    #[test]
+    fn f401_2() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/F401_2.py"),
+            &settings::Settings::for_rule(CheckCode::F401),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
+
+    #[test]
+    fn f401_3() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/F401_3.py"),
+            &settings::Settings::for_rule(CheckCode::F401),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
+
+    #[test]
+    fn f401_4() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/F401_4.py"),
             &settings::Settings::for_rule(CheckCode::F401),
             &fixer::Mode::Generate,
         )?;
@@ -714,42 +762,6 @@ mod tests {
         Ok(())
     }
 
-    #[test]
-    fn m001() -> Result<()> {
-        let mut checks = check_path(
-            Path::new("./resources/test/fixtures/M001.py"),
-            &settings::Settings::for_rules(vec![CheckCode::M001, CheckCode::E501, CheckCode::F841]),
-            &fixer::Mode::Generate,
-        )?;
-        checks.sort_by_key(|check| check.location);
-        insta::assert_yaml_snapshot!(checks);
-        Ok(())
-    }
-
-    #[test]
-    fn init() -> Result<()> {
-        let mut checks = check_path(
-            Path::new("./resources/test/fixtures/__init__.py"),
-            &settings::Settings::for_rules(vec![CheckCode::F821, CheckCode::F822]),
-            &fixer::Mode::Generate,
-        )?;
-        checks.sort_by_key(|check| check.location);
-        insta::assert_yaml_snapshot!(checks);
-        Ok(())
-    }
-
-    #[test]
-    fn future_annotations() -> Result<()> {
-        let mut checks = check_path(
-            Path::new("./resources/test/fixtures/future_annotations.py"),
-            &settings::Settings::for_rules(vec![CheckCode::F401, CheckCode::F821]),
-            &fixer::Mode::Generate,
-        )?;
-        checks.sort_by_key(|check| check.location);
-        insta::assert_yaml_snapshot!(checks);
-        Ok(())
-    }
-
     #[test]
     fn e999() -> Result<()> {
         let mut checks = check_path(
@@ -798,6 +810,42 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn b011() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/B011.py"),
+            &settings::Settings::for_rule(CheckCode::B011),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
+
+    #[test]
+    fn b014() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/B014.py"),
+            &settings::Settings::for_rule(CheckCode::B014),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
+
+    #[test]
+    fn b025() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/B025.py"),
+            &settings::Settings::for_rule(CheckCode::B025),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
+
     #[test]
     fn c400() -> Result<()> {
         let mut checks = check_path(
@@ -894,6 +942,30 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn c409() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/C409.py"),
+            &settings::Settings::for_rule(CheckCode::C409),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
+
+    #[test]
+    fn c410() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/C410.py"),
+            &settings::Settings::for_rule(CheckCode::C410),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
+
     #[test]
     fn c415() -> Result<()> {
         let mut checks = check_path(
@@ -907,10 +979,10 @@ mod tests {
     }
 
     #[test]
-    fn spr001() -> Result<()> {
+    fn u008() -> Result<()> {
         let mut checks = check_path(
-            Path::new("./resources/test/fixtures/SPR001.py"),
-            &settings::Settings::for_rule(CheckCode::SPR001),
+            Path::new("./resources/test/fixtures/U008.py"),
+            &settings::Settings::for_rule(CheckCode::U008),
             &fixer::Mode::Generate,
         )?;
         checks.sort_by_key(|check| check.location);
@@ -1025,4 +1097,40 @@ mod tests {
         insta::assert_yaml_snapshot!(checks);
         Ok(())
     }
+
+    #[test]
+    fn m001() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/M001.py"),
+            &settings::Settings::for_rules(vec![CheckCode::M001, CheckCode::E501, CheckCode::F841]),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
+
+    #[test]
+    fn init() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/__init__.py"),
+            &settings::Settings::for_rules(vec![CheckCode::F821, CheckCode::F822]),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
+
+    #[test]
+    fn future_annotations() -> Result<()> {
+        let mut checks = check_path(
+            Path::new("./resources/test/fixtures/future_annotations.py"),
+            &settings::Settings::for_rules(vec![CheckCode::F401, CheckCode::F821]),
+            &fixer::Mode::Generate,
+        )?;
+        checks.sort_by_key(|check| check.location);
+        insta::assert_yaml_snapshot!(checks);
+        Ok(())
+    }
 }
