@@ -5,93 +5,33 @@ use std::sync::mpsc::channel;
 use std::time::Instant;
 
 use anyhow::Result;
-use clap::{command, Parser};
+use clap::Parser;
 use colored::Colorize;
 use log::{debug, error};
 use notify::{raw_watcher, RecursiveMode, Watcher};
 use rayon::prelude::*;
-use regex::Regex;
 use walkdir::DirEntry;
 
-use ::ruff::cache;
-use ::ruff::checks::CheckCode;
-use ::ruff::checks::CheckKind;
-use ::ruff::fs::iter_python_files;
-use ::ruff::linter::add_noqa_to_path;
-use ::ruff::linter::lint_path;
-use ::ruff::logging::set_up_logging;
-use ::ruff::message::Message;
-use ::ruff::printer::{Printer, SerializationFormat};
-use ::ruff::pyproject::{self, StrCheckCodePair};
-use ::ruff::settings::CurrentSettings;
-use ::ruff::settings::{FilePattern, PerFileIgnore, Settings};
-use ::ruff::tell_user;
+use ruff::cache;
+use ruff::checks::CheckCode;
+use ruff::checks::CheckKind;
+use ruff::cli::{warn_on, Cli, Warnable};
+use ruff::fs::iter_python_files;
+use ruff::linter::add_noqa_to_path;
+use ruff::linter::autoformat_path;
+use ruff::linter::lint_path;
+use ruff::logging::set_up_logging;
+use ruff::message::Message;
+use ruff::printer::{Printer, SerializationFormat};
+use ruff::pyproject::{self};
+use ruff::settings::CurrentSettings;
+use ruff::settings::RawSettings;
+use ruff::settings::{FilePattern, PerFileIgnore, Settings};
+use ruff::tell_user;
 
 const CARGO_PKG_NAME: &str = env!("CARGO_PKG_NAME");
 const CARGO_PKG_VERSION: &str = env!("CARGO_PKG_VERSION");
 
-#[derive(Debug, Parser)]
-#[command(author, about = "ruff: An extremely fast Python linter.")]
-#[command(version)]
-struct Cli {
-    #[arg(required = true)]
-    files: Vec<PathBuf>,
-    /// Enable verbose logging.
-    #[arg(short, long)]
-    verbose: bool,
-    /// Disable all logging (but still exit with status code "1" upon detecting errors).
-    #[arg(short, long)]
-    quiet: bool,
-    /// Exit with status code "0", even upon detecting errors.
-    #[arg(short, long)]
-    exit_zero: bool,
-    /// Run in watch mode by re-running whenever files change.
-    #[arg(short, long)]
-    watch: bool,
-    /// Attempt to automatically fix lint errors.
-    #[arg(short, long)]
-    fix: bool,
-    /// Disable cache reads.
-    #[arg(short, long)]
-    no_cache: bool,
-    /// List of error codes to enable.
-    #[arg(long, value_delimiter = ',')]
-    select: Vec<CheckCode>,
-    /// Like --select, but adds additional error codes on top of the selected ones.
-    #[arg(long, value_delimiter = ',')]
-    extend_select: Vec<CheckCode>,
-    /// List of error codes to ignore.
-    #[arg(long, value_delimiter = ',')]
-    ignore: Vec<CheckCode>,
-    /// Like --ignore, but adds additional error codes on top of the ignored ones.
-    #[arg(long, value_delimiter = ',')]
-    extend_ignore: Vec<CheckCode>,
-    /// List of paths, used to exclude files and/or directories from checks.
-    #[arg(long, value_delimiter = ',')]
-    exclude: Vec<String>,
-    /// Like --exclude, but adds additional files and directories on top of the excluded ones.
-    #[arg(long, value_delimiter = ',')]
-    extend_exclude: Vec<String>,
-    /// List of mappings from file pattern to code to exclude
-    #[arg(long, value_delimiter = ',')]
-    per_file_ignores: Vec<StrCheckCodePair>,
-    /// Output serialization format for error messages.
-    #[arg(long, value_enum, default_value_t=SerializationFormat::Text)]
-    format: SerializationFormat,
-    /// See the files ruff will be run against with the current settings.
-    #[arg(long)]
-    show_files: bool,
-    /// See ruff's settings.
-    #[arg(long)]
-    show_settings: bool,
-    /// Enable automatic additions of noqa directives to failing lines.
-    #[arg(long)]
-    add_noqa: bool,
-    /// Regular expression matching the name of dummy variables.
-    #[arg(long)]
-    dummy_variable_rgx: Option<Regex>,
-}
-
 #[cfg(feature = "update-informer")]
 fn check_for_updates() {
     use update_informer::{registry, Check};
@@ -116,8 +56,11 @@ fn check_for_updates() {
     }
 }
 
-fn show_settings(settings: Settings) {
-    println!("{:#?}", CurrentSettings::from_settings(settings));
+fn show_settings(settings: RawSettings, project_root: Option<PathBuf>, pyproject: Option<PathBuf>) {
+    println!(
+        "{:#?}",
+        CurrentSettings::from_settings(settings, project_root, pyproject)
+    );
 }
 
 fn show_files(files: &[PathBuf], settings: &Settings) {
@@ -165,7 +108,7 @@ fn run_once(
             }
             .unwrap_or_else(|(path, message)| {
                 if let Some(path) = path {
-                    if settings.select.contains(&CheckCode::E902) {
+                    if settings.enabled.contains(&CheckCode::E902) {
                         vec![Message {
                             kind: CheckKind::IOError(message),
                             fixed: false,
@@ -222,6 +165,33 @@ fn add_noqa(files: &[PathBuf], settings: &Settings) -> Result<usize> {
     Ok(modifications)
 }
 
+fn autoformat(files: &[PathBuf], settings: &Settings) -> Result<usize> {
+    // Collect all the files to format.
+    let start = Instant::now();
+    let paths: Vec<DirEntry> = files
+        .iter()
+        .flat_map(|path| iter_python_files(path, &settings.exclude, &settings.extend_exclude))
+        .flatten()
+        .collect();
+    let duration = start.elapsed();
+    debug!("Identified files to lint in: {:?}", duration);
+
+    let start = Instant::now();
+    let modifications = paths
+        .par_iter()
+        .map(|entry| {
+            let path = entry.path();
+            autoformat_path(path)
+        })
+        .flatten()
+        .count();
+
+    let duration = start.elapsed();
+    debug!("Auto-formatted files in: {:?}", duration);
+
+    Ok(modifications)
+}
+
 fn inner_main() -> Result<ExitCode> {
     let cli = Cli::parse();
 
@@ -256,7 +226,7 @@ fn inner_main() -> Result<ExitCode> {
         .map(|pair| PerFileIgnore::new(pair, &project_root))
         .collect();
 
-    let mut settings = Settings::from_pyproject(pyproject, project_root)?;
+    let mut settings = RawSettings::from_pyproject(&pyproject, &project_root)?;
     if !exclude.is_empty() {
         settings.exclude = exclude;
     }
@@ -267,17 +237,35 @@ fn inner_main() -> Result<ExitCode> {
         settings.per_file_ignores = per_file_ignores;
     }
     if !cli.select.is_empty() {
-        settings.clear();
-        settings.select(cli.select);
+        warn_on(
+            Warnable::Select,
+            &cli.select,
+            &cli.ignore,
+            &cli.extend_ignore,
+            &settings,
+            &pyproject,
+        );
+        settings.select = cli.select;
     }
     if !cli.extend_select.is_empty() {
-        settings.select(cli.extend_select);
+        warn_on(
+            Warnable::ExtendSelect,
+            &cli.extend_select,
+            &cli.ignore,
+            &cli.extend_ignore,
+            &settings,
+            &pyproject,
+        );
+        settings.extend_select = cli.extend_select;
     }
     if !cli.ignore.is_empty() {
-        settings.ignore(&cli.ignore);
+        settings.ignore = cli.ignore;
     }
     if !cli.extend_ignore.is_empty() {
-        settings.ignore(&cli.extend_ignore);
+        settings.extend_ignore = cli.extend_ignore;
+    }
+    if let Some(target_version) = cli.target_version {
+        settings.target_version = target_version;
     }
     if let Some(dummy_variable_rgx) = cli.dummy_variable_rgx {
         settings.dummy_variable_rgx = dummy_variable_rgx;
@@ -287,12 +275,15 @@ fn inner_main() -> Result<ExitCode> {
         eprintln!("Error: specify --show-settings or show-files (not both).");
         return Ok(ExitCode::FAILURE);
     }
-    if cli.show_files {
-        show_files(&cli.files, &settings);
+    if cli.show_settings {
+        show_settings(settings, project_root, pyproject);
         return Ok(ExitCode::SUCCESS);
     }
-    if cli.show_settings {
-        show_settings(settings);
+
+    let settings = Settings::from_raw(settings);
+
+    if cli.show_files {
+        show_files(&cli.files, &settings);
         return Ok(ExitCode::SUCCESS);
     }
 
@@ -308,6 +299,10 @@ fn inner_main() -> Result<ExitCode> {
             eprintln!("Warning: --no-qa is not enabled in watch mode.");
         }
 
+        if cli.autoformat {
+            eprintln!("Warning: --autoformat is not enabled in watch mode.");
+        }
+
         if cli.format != SerializationFormat::Text {
             eprintln!("Warning: --format 'text' is used in watch mode.");
         }
@@ -351,6 +346,11 @@ fn inner_main() -> Result<ExitCode> {
         if modifications > 0 {
             println!("Added {modifications} noqa directives.");
         }
+    } else if cli.autoformat {
+        let modifications = autoformat(&cli.files, &settings)?;
+        if modifications > 0 {
+            println!("Formatted {modifications} files.");
+        }
     } else {
         let messages = run_once(&cli.files, &settings, !cli.no_cache, cli.fix)?;
         if !cli.quiet {
@@ -360,7 +360,7 @@ fn inner_main() -> Result<ExitCode> {
         #[cfg(feature = "update-informer")]
         check_for_updates();
 
-        if !messages.is_empty() && !cli.exit_zero {
+        if messages.iter().any(|message| !message.fixed) && !cli.exit_zero {
             return Ok(ExitCode::FAILURE);
         }
     }
