@@ -104,9 +104,7 @@ fn add_noqa_inner(
             .unwrap_or(lineno);
 
         if !codes.is_empty() {
-            let matches = matches_by_line
-                .entry(noqa_lineno)
-                .or_insert_with(BTreeSet::new);
+            let matches = matches_by_line.entry(noqa_lineno).or_default();
             matches.append(&mut codes);
         }
     }
@@ -127,7 +125,7 @@ fn add_noqa_inner(
                     Directive::All(start, _) => output.push_str(&line[..start]),
                     Directive::Codes(start, _, _) => output.push_str(&line[..start]),
                 };
-                let codes: Vec<&str> = codes.iter().map(|code| code.as_str()).collect();
+                let codes: Vec<&str> = codes.iter().map(|code| code.as_ref()).collect();
                 output.push_str("  # noqa: ");
                 output.push_str(&codes.join(", "));
                 output.push('\n');
@@ -152,12 +150,12 @@ pub fn add_noqa(
 
 #[cfg(test)]
 mod tests {
-    use crate::ast::types::Range;
     use anyhow::Result;
     use rustpython_parser::ast::Location;
     use rustpython_parser::lexer;
     use rustpython_parser::lexer::LexResult;
 
+    use crate::ast::types::Range;
     use crate::checks::{Check, CheckKind};
     use crate::noqa::{add_noqa_inner, extract_noqa_line_for};
 
